cis_config: seri_t Struct Reference

cis_config

Public Attributes | List of all members
seri_t Struct Reference

Serializer structure. More...

`#include <SerializeBase.h>`

## Public Attributes
seri_type | type
| Serializer type.
void * | info
| Pointer to any extra info serializer requires.
size_t | size_info
| Size of allocate space for info.

## Detailed Description

Serializer structure.

The documentation for this struct was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/serialize/SerializeBase.h